#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS

TS=PASS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-queueonly.rc

${KCOV_OUTSIDE}6-0 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}6-0" -h ALL
${KCOV_THROUGH}6-0-1 /usr/bin/msmtpq-ng -bp | grep -qiE '^[0-9.][0-9.]*(!|-)'
MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng-queue -bp has no non-held messages to display"

TS=PASS

sed -i -e '$a\export MSMTP_SEND_DELAY=14400' ./tmp/msmtpq-ng-queueonly.rc

 MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-1 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}6-1" -H ALL
grep -qi 'too new to release' ./tmp/msmtp.queue.only.log

MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng-queue -H ALL has messages too new to release"

TS=PASS

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-queueonly-syslog.rc

MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-2 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}6-2" -H ALL

sudo journalctl -t msmtpq-ng|grep -q 'too new to release'
MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng-queue -H ALL with syslog and messages too new to release "
sed -i -e '/export MSMTP_SEND_DELAY=14400/d' ./tmp/msmtpq-ng-queueonly.rc

TS=PASS

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-queueonly-syslog.rc
sed -i -e 's/^export MSMTP_QUEUE_ONLY=true/export MSMTP_QUEUE_ONLY=false/' ./tmp/msmtpq-ng-queueonly-syslog.rc

MID="$(grep 'enqueued mail as : \[ .* \] ' ./tmp/msmtp.queue.only.log|tail -n1|cut -f4 -d\[|cut -f1 -d]|tr -d ' ')"

 MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-3 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}6-3" -qI "$MID"

sudo journalctl -t msmtpq-ng | grep -q 'too new to unhold'

MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng -q with syslog and messages too new to release "

sed -i -e 's/^export MSMTP_QUEUE_ONLY=false/export MSMTP_QUEUE_ONLY=true/' ./tmp/msmtpq-ng-queueonly-syslog.rc

TS=PASS

sed -i -e 's/^export MSMTP_QUEUE_ONLY=true/export MSMTP_QUEUE_ONLY=false/' ./tmp/msmtpq-ng-queueonly.rc
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-queueonly.rc
MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_THROUGH}6-4 /usr/bin/msmtpq-ng-queue -f | grep -q 'mail queue is empty'
MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng-queue -f shows mail queue is empty"

TS=PASS

sed -i -e '$a\export MSMTP_MAXIMUM_QUEUE_LIFETIME=0' ./tmp/msmtpq-ng-queueonly.rc
sed -i -e 's/^export MSMTP_SEND_DELAY=14400/export MSMTP_SEND_DELAY=0/' ./tmp/msmtpq-ng-queueonly.rc
sed -i -e 's,^export MSMTP=.*,export MSMTP=./tests/scripts/msmtp-fail,' ./tmp/msmtpq-ng-queueonly.rc
sed -i -e 's/^export MSMTP_QUEUE_ONLY=true/export MSMTP_QUEUE_ONLY=false/' ./tmp/msmtpq-ng-queueonly.rc
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-queueonly.rc
 MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_THROUGH}6-5 /usr/bin/msmtpq-ng-queue -H ALL
/usr/bin/msmtpq-ng -q | grep -q 'exceeded queue lifetime; purged'
MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng -q with small max lifetime purges queue"

sed -i -e '/export MSMTP_MAXIMUM_QUEUE_LIFETIME=0/d' ./tmp/msmtpq-ng-queueonly.rc
sed -i -e 's/^export MSMTP_SEND_DELAY=0/export MSMTP_SEND_DELAY=14400/' ./tmp/msmtpq-ng-queueonly.rc
MSMTP_MAXIMUM_QUEUE_LIFETIME=345600
MSMTP_SEND_DELAY=14400
export MSMTP_MAXIMUM_QUEUE_LIFETIME MSMTP_SEND_DELAY

rm -rf ./tmp/msmtp.queue
rm -f ./tmp/msmtp.queue.log

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng.rc

TS=PASS

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log
printf  "" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-6 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}6-6" root || TS=FAIL
grep -qi 'empty body' ./tmp/msmtp.queue.log 2>/dev/null || TS=FAIL
[ -n "$(ls -A ./tmp/msmtp.queue/*.mail 2>/dev/null)" ] && TS=FAIL

echo "$TS: Sending empty body emits log (if debug) but not error."

if [ "$TS" = "FAIL" ]; then
	OTS=FAIL
fi

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-fail.rc

TS=PASS

echo "Subject: Test mail queueing

Test mail queueing" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-7 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}6-7" root || true

grep -q 'EX_UNAVAIL' ./tmp/msmtp.queue.log 2>/dev/null || TS=FAIL
grep -q 'Test mail queueing' ./tmp/msmtp.queue/*.mail 2>/dev/null || TS=FAIL

echo "$TS: Sending a body queues mail"

if [ "$TS" = "FAIL" ]; then
	OTS=FAIL
fi

TS=PASS

/usr/bin/msmtpq-ng-queue |tail -n+3|head -n-1|head -n1|cut -f1 -d\*  >./tmp/qtestid
MQRC=$?

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Showing mail queue succeeds"

TS=PASS

 MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-8 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}6-8" -s "$(cat ./tmp/qtestid)"
MQRC=$?

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Showing single message from queue succeeds"

TS=PASS

 MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-9 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}6-9" -h "$(cat ./tmp/qtestid)"
MQRC=$?

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Putting a single message on hold succeeds"

TS=PASS

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-queueonly.rc

sed -i -e '$a\export MSMTP_SEND_DELAY=0' ./tmp/msmtpq-ng-queueonly.rc
sed -i -e '$a\export MSMTP_QUEUE_ONLY=true' ./tmp/msmtpq-ng-queueonly.rc

echo "Subject: Add a non-held message

Test a non-held message queue run after failure." | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-10 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}6-10" root

MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_THROUGH}6-10-2 /usr/bin/msmtpq-ng-queue -f
grep -q 'Not running queue' ./tmp/msmtp.queue.only.log

MQRC="$?"

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Queue run fails with queue only enabled"

TS=PASS


sed -i -e '/export MSMTP_QUEUE_ONLY=true/d' ./tmp/msmtpq-fail.rc
sed -i -e '/export MSMTP_QUEUE_FIRST=true/d' ./tmp/msmtpq-fail.rc
sed -i -e '/export MSMTP_SEND_DELAY=.*/d' ./tmp/msmtpq-fail.rc
sed -i -e '$a\export MSMTP_QUEUE_ONLY=false' ./tmp/msmtpq-fail.rc
sed -i -e '$a\export MSMTP_QUEUE_FIRST=false' ./tmp/msmtpq-fail.rc
sed -i -e '$a\export MSMTP_SEND_DELAY=0' ./tmp/msmtpq-fail.rc

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-fail.rc

#/usr/bin/msmtpq-ng-queue |tail -n+3|head -n-1|head -n1|cut -f1 -d\*  >./tmp/qtestid
MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-11 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}6-11" -h "$(cat ./tmp/qtestid)"

MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-12 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}6-12" -i "$(cat ./tmp/qtestid)"
grep -q 'send failed' ./tmp/msmtp.queue.log

MQRC="$?"

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Flushing a single held message fails if no connectivty"

TS=PASS

 MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-13 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}6-13" -H "$(cat ./tmp/qtestid)"
MQRC=$?

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Taking a single message off hold succeeds"

TS=PASS

 MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}6-14 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}6-14" -d "$(cat ./tmp/qtestid)"
MQRC=$?

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Purging a single message succeeds"

sed -i -e '/export MSMTP_SEND_DELAY=0/d' ./tmp/msmtpq-fail.rc
sed -i -e '/export MSMTP_QUEUE_FIRST=false/d' ./tmp/msmtpq-fail.rc

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi
