#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-fail.rc

chmod a+w ./tmp/msmtp.queue || true
rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

TS=PASS

echo "Subject: Test mail queueing with dots

Test mail queueing with dots
test
.test4
..test3

.
test2" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}7-1 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}7-1" root || true

grep -q 'test2' ./tmp/msmtp.queue/*.mail 2>/dev/null && {
	TS=FAIL
	OTS=FAIL
}

echo "$TS: Sending a dot in body ends mail"

TS=PASS

grep -q '^\.\.test3' ./tmp/msmtp.queue/*.mail 2>/dev/null || {
	TS=FAIL
	OTS=FAIL
}

echo "$TS: Multiple leading dots are preserved"

TS=PASS

grep -q '^\.test4' ./tmp/msmtp.queue/*.mail 2>/dev/null || {
	TS=FAIL
	OTS=FAIL
}

echo "$TS: Single leading dots are preserved"

TS=PASS

rm -rf ./tmp/msmtp.queue/*
tail -n+3 ./tmp/msmtp.queue/*.mail 2>&1 | grep -q '^$' && {
	TS=FAIL
	OTS=FAIL
}

echo "Subject: Test mail queueing with dots

Test mail queueing with empty lines in body

test2" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}7-2 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}7-2" root || true

echo "$TS: Empty lines in body are ignored"

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

TS=PASS

echo "Subject: Test mail queueing ignoring dots

Test mail queueing ignoring dots
test
.
test2" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}7-3 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}7-3" -i root || true

grep -q 'test2' ./tmp/msmtp.queue/*.mail 2>/dev/null || {
	TS=FAIL
	OTS=FAIL
}

echo "$TS: Sending a dot in body does not end mail when ignoring dots"

[ "$TS" = "FAIL" ] && OTS=FAIL || true

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi
