#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=FAIL

if [ -r /etc/os-release ]; then
	. /etc/os-release

	[ -z "$ID_LIKE" ] && ID_LIKE="${ID}" || true

	if echo "$ID_LIKE" | grep -q rhel; then
		VERSION=1.2.5.1
		if [ -n "$(command -v rpmbuild)" ]; then
			git archive --prefix=msmtp-scripts-${VERSION}/ -o ../msmtp-scripts-${VERSION}.tar.gz HEAD && OTS=SUCCESS
			if [ "$OTS" = "SUCCESS" ]; then
				rpmbuild --quiet -ta ../msmtp-scripts-${VERSION}.tar.gz || OTS=FAIL
			fi
			if [ "$OTS" = "SUCCESS" ]; then
				echo "PASS: Enterprise Linux package build succeeded"
			else
				echo "FAIL: Enterprise Linux package build failed"
			fi

		else
			echo "SKIP: Skipping enterprise linux package build on host without rpmbuild"
			OTS=SKIP
		fi
	else
		echo "SKIP: Skipping enterprise linux package build on non-el host"
		OTS=SKIP
	fi
else
	OTS=FAIL
	echo "FAIL: Unable to determine OS type"
fi

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi
